# Copyright 2025 WhoMeta Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Export helpers: UAP → MCP template (stub implementation).

Generated by WhoMeta Unified Agent Protocol SDK
"""
from __future__ import annotations

from typing import Dict, Union

from unifiedagentprotocol.models.agent import Agent
from unifiedagentprotocol.models.tool import Tool


def agent_to_mcp(obj: Union[Agent, Tool]) -> Dict:  # noqa: D401 ANN401
    """Return a minimal MCP template JSON object.

    For demonstration, we wrap UAP representation inside the `template` field.
    """

    return {
        "version": "0.1",
        "template": obj.dict(by_alias=True),
    }
